#!/usr/bin/env bash

# Check if desktop environment is installed
if ! dpkg -s ${DESKTOP_ENVIRONMENT} &> /dev/null; then
  sudo apt-get update
  DEBIAN_FRONTEND=noninteractive sudo apt-get install -y ${DESKTOP_ENVIRONMENT} libdatetime-perl
else
  echo "${DESKTOP_ENVIRONMENT} is already installed."
fi

# Check if vncserver is installed
if ! dpkg -s kasmvncserver &> /dev/null; then
  DISTRO=$(lsb_release -c -s)
  ARCH=$(dpkg --print-architecture)
  wget -q https://github.com/kasmtech/KasmVNC/releases/download/v${VERSION}/kasmvncserver_$${DISTRO}_${VERSION}_$${ARCH}.deb -O /tmp/kasmvncserver.deb
  sudo apt-get install -y /tmp/kasmvncserver.deb
  printf "🥳 KasmVNC v${VERSION} has been successfully installed!\n\n"
  sudo rm -f /tmp/kasmvncserver.deb
else
  echo "KasmVNC is already installed."
fi

sudo addgroup $USER ssl-cert

# Coder port-forwarding from dashboard only supports HTTP
sudo bash -c "cat > /etc/kasmvnc/kasmvnc.yaml <<EOF
network:
  protocol: http
  websocket_port: ${PORT}
  ssl:
    require_ssl: false
  udp:
    public_ip: 127.0.0.1
EOF"

# This password is not used since we start the server without auth.
# The server is protected via the Coder session token / tunnel
# and does not listen publicly on the VM
echo -e "password\npassword\n" | vncpasswd -wo -u $USER

# Start the server
printf "🚀 Starting KasmVNC server...\n"
sudo -u $USER bash -c 'vncserver -select-de "${DESKTOP_ENVIRONMENT}" -disableBasicAuth' > /tmp/kassmvncserver.log 2>&1 &
